summaryrefslogtreecommitdiffstats
path: root/src/usr/errl/plugins
diff options
context:
space:
mode:
authorMike Jones <mjjones@us.ibm.com>2013-03-19 09:47:46 -0500
committerA. Patrick Williams III <iawillia@us.ibm.com>2013-03-28 09:56:18 -0500
commitec276b3e9da8acb4a3d26e6574ab521a785d1493 (patch)
treec4a4275242652fbbdf5ebafdc756d8a724397317 /src/usr/errl/plugins
parentb2825953b28bea95f4ae46fd268d4e06dcb87455 (diff)
downloadblackbird-hostboot-ec276b3e9da8acb4a3d26e6574ab521a785d1493.tar.gz
blackbird-hostboot-ec276b3e9da8acb4a3d26e6574ab521a785d1493.zip
Errlog Parser: Look in nfs and maint for syms file when parsing backtrace
Change-Id: Iad2bc4806787b3d2324f4defa0775595a7810f0f RTC: 63499 Reviewed-on: http://gfw160.austin.ibm.com:8080/gerrit/3627 Reviewed-by: Brian H. Horton <brianh@linux.ibm.com> Tested-by: Jenkins Server Reviewed-by: Richard J. Knight <rjknight@us.ibm.com> Reviewed-by: Nicholas E. Bofferding <bofferdn@us.ibm.com> Reviewed-by: A. Patrick Williams III <iawillia@us.ibm.com>
Diffstat (limited to 'src/usr/errl/plugins')
-rw-r--r--src/usr/errl/plugins/errludbacktrace.H24
1 files changed, 19 insertions, 5 deletions
diff --git a/src/usr/errl/plugins/errludbacktrace.H b/src/usr/errl/plugins/errludbacktrace.H
index ad60e9c3e..1d8e9d8fa 100644
--- a/src/usr/errl/plugins/errludbacktrace.H
+++ b/src/usr/errl/plugins/errludbacktrace.H
@@ -80,14 +80,28 @@ public:
BACKTRACE_ENTRY_SYMBOL_SIZE);
// Initialize l_the symbol table.
- const char * l_pSymFile = "hbicore.syms";
+ const char * const l_pNfsSymFile = "/nfs/data/hbicore.syms";
hbSymbolTable symTab;
- int readRC = symTab.readSymbols( l_pSymFile );
+ int readRC = symTab.readSymbols( l_pNfsSymFile );
if( readRC )
{
- i_parser.PrintString( "Symbols not found", l_pSymFile );
- // symTab.nearestSymbol() will return NULL because of this.
- // Carry on.
+ // Not found in NFS, look in maint for symbol file
+ const char * const l_pMaintSymFile = "/maint/data/hbicore.syms";
+ readRC = symTab.readSymbols( l_pMaintSymFile );
+
+ if( readRC )
+ {
+ // Not found in maint, look in pwd
+ const char * const l_pPwdSymFile = "hbicore.syms";
+ readRC = symTab.readSymbols( l_pPwdSymFile );
+
+ if( readRC )
+ {
+ i_parser.PrintString( "Symbols not found", l_pPwdSymFile );
+ // symTab.nearestSymbol() will return NULL because of this.
+ // Carry on.
+ }
+ }
}
const char * l_pErrlEntry = "ErrlEntry::ErrlEntry";
OpenPOWER on IntegriCloud